@@ -80,7 +80,8 @@ sub draw {
     $self->panel->endGroup($gd);
     return $retval;
   } else {
-      return $self->Bio::Graphics::Glyph::box::draw(@_);
+      # This draws a filled box for null value data
+      #return $self->Bio::Graphics::Glyph::box::draw(@_);
   }
 }
 
@@ -168,6 +169,7 @@ sub draw_segment {
   my $data    = ref $seg_data eq 'ARRAY' ? $seg_data
                                          : $seg_data->values($start,$end,$samples);
 
+
   # scale the glyph if the data end before the panel does
   my $data_width = $end - $start;
   my $data_width_ratio;
@@ -358,6 +360,7 @@ sub draw_plot {
     $self->panel->startGroup($gd);
     foreach (@$parts) {
 	my ($start,$end,$score) = @$_;
+	next unless defined $score; # undefined (absent) score transparent
 	$score    = ($score-$mean)/$stdev if $rescale;
 	$score    = $scaled_min if $scaled_min > $score;
 	$score    = $scaled_max if $scaled_max < $score;
@@ -401,6 +404,7 @@ sub _draw_coverage {
 	my $s      = $start + $offset;
 	my $e      = $s+1;  # fill in gaps
 	my $v      = $array->[$offset/$bases_per_bin];
+	#$v         = 0 unless defined $v; # don't want undefined values
 	push @parts,[$s,$s,$v];
     }
     $self->Bio::Graphics::Glyph::wiggle_density::draw_plot(\@parts,@_);
@@ -411,7 +415,7 @@ sub calculate_color {
   my ($s,$rgb,$min_score,$max_score) = @_;
   $s ||= $min_score;
 
-  return (255,255,255) if $max_score <= $min_score; # avoid div by zero
+  return (255,255,255) unless $max_score - $min_score; # avoid div by zero
 
   my $relative_score = ($s-$min_score)/($max_score-$min_score);
   $relative_score    = 0 if $relative_score < 0;
